---
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

```{raw-cell}

---

This is a complex paragraph
that is split over multiple lines.

It also includes blank lines.


---
```

```{code-cell}
print("Hello, World!")
```
